mrr

Function mrr 

pub fn mrr(returned: &[Uuid], relevant: &[Uuid]) -> f32
Mean Reciprocal Rank: the reciprocal of the rank of the first relevant result.

If no relevant result is found in the returned list, returns 0.0. Rank is 1-indexed (first position = rank 1).